==> plasma-desktop-5.13.2.tar.xz: plasma-desktop-5.13.2/kcms/qtquicksettings/kcmqtquicksettings.h <==
/*  This file is part of the KDE's Plasma desktop
 *  Copyright 2017 David Edmundson <davidedmundson@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#pragma once

#include <KCModule>
#include <KSharedConfig>
#include <KConfigGroup>

namespace Ui
{
class KCMQtQuickSettingsWidget;
}

namespace PlasmaQtQuickSettings
{
class RendererSettings;
}

/**
 * @short A KCM to configure Plasma QtQuick settings
 */
class KCMQtQuickSettingsModule : public KCModule
{
    Q_OBJECT

public:
    KCMQtQuickSettingsModule(QWidget *parent, const QVariantList &);
    virtual ~KCMQtQuickSettingsModule();

    void load() Q_DECL_OVERRIDE;
    void save() Q_DECL_OVERRIDE;
    void defaults() Q_DECL_OVERRIDE;

private:
    QScopedPointer<Ui::KCMQtQuickSettingsWidget> m_ui;
    QScopedPointer<PlasmaQtQuickSettings::RendererSettings> m_settings;
};

==> plasma-desktop_5.14.5.2+rb2.orig.tar.xz: plasma-desktop-5.14.5.2+rb2/kcms/qtquicksettings/kcmqtquicksettings.h <==
/*  This file is part of the KDE's Plasma desktop
 *  Copyright 2017 David Edmundson <davidedmundson@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#pragma once

#include <KCModule>
#include <KSharedConfig>
#include <KConfigGroup>

namespace Ui
{
class KCMQtQuickSettingsWidget;
}

namespace PlasmaQtQuickSettings
{
class RendererSettings;
}

/**
 * @short A KCM to configure Plasma QtQuick settings
 */
class KCMQtQuickSettingsModule : public KCModule
{
    Q_OBJECT

public:
    explicit KCMQtQuickSettingsModule(QWidget *parent, const QVariantList &);
    ~KCMQtQuickSettingsModule() override;

    void load() override;
    void save() override;
    void defaults() override;

private:
    QScopedPointer<Ui::KCMQtQuickSettingsWidget> m_ui;
    QScopedPointer<PlasmaQtQuickSettings::RendererSettings> m_settings;
};
